package com.muyu.marketing.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.marketing.domain.model.*;
import lombok.*;
import lombok.experimental.SuperBuilder;

import java.math.BigDecimal;

@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName(value = "activity_team_product_sku_info", autoResultMap = true)
public class ActivityTeamProductSkuInfo extends BaseEntity {

  /**
   * 主键
   */
  @TableId(value = "id", type = IdType.AUTO)
  private long id;
  /**
   * 活动ID
   */
  private long teamId;
  /**
   * 商品ID
   */
  private Long productId;
  /**
   * 商品SKU
   */
  private String productSku;
  /**
   * 拼团库存
   */
  private Long teamStock;
  /**
   * 剩余库存
   */
  private Long remainStock;
  /**
   * 拼团价格
   */
  private BigDecimal teamPrice;

  /**
   * 通过模型钢构件对象
   * @param activityTeamProductSkuAddModel 模型
   * @return 对象
   */
  public static ActivityTeamProductSkuInfo modelBuild(ActivityTeamProductSkuAddModel activityTeamProductSkuAddModel) {
    return ActivityTeamProductSkuInfo.builder()
            .productId(activityTeamProductSkuAddModel.getProductId())
            .teamId(activityTeamProductSkuAddModel.getTeamId())
            .teamStock(activityTeamProductSkuAddModel.getTeamStock())
            .productSku(activityTeamProductSkuAddModel.getSku())
            .teamPrice(activityTeamProductSkuAddModel.getTeamPrice())
            .build();
  }


  public static ActivityTeamProductSkuInfo updateModelBuild(ActivityTeamProductSkuReqModel activityTeamProductSkuReqModel) {
    return ActivityTeamProductSkuInfo.builder()
            .id(activityTeamProductSkuReqModel.getId())
            .productId(activityTeamProductSkuReqModel.getProductId())
            .teamStock(activityTeamProductSkuReqModel.getTeamStock())
            .productSku(activityTeamProductSkuReqModel.getProductSku())
            .teamPrice(activityTeamProductSkuReqModel.getTeamPrice())
            .build();
  }

  /**
   * 批量修改的构造器
   * @param activityTeamProductSkuModel
   * @return
   */
  public static ActivityTeamProductSkuInfo batchUpdate(ActivityTeamProductSkuUpdModel activityTeamProductSkuModel){
    return ActivityTeamProductSkuInfo.builder()
            .id(activityTeamProductSkuModel.getId())
            .teamPrice(activityTeamProductSkuModel.getTeamPrice())
            .teamStock(activityTeamProductSkuModel.getTeamStock())
            .build();
  }


  public static ActivityTeamProductSkuInfo batchSaveSku(ActivityTeamProductSkuAddModel activityTeamProductSkuAddModel){
    return ActivityTeamProductSkuInfo.builder()
            .productSku(activityTeamProductSkuAddModel.getSku())
            .teamStock(activityTeamProductSkuAddModel.getTeamStock())
            .teamPrice(activityTeamProductSkuAddModel.getTeamPrice())
            .build();
  }

//  public static ActivityTeamProductSkuInfo addSuk(ActivityTeamInfoUpdModel ActivityTeamInfoUpdModel){
//    return ActivityTeamProductSkuInfo.builder()
//            .productSku(activityTeamProductSkuAddModel.getSku())
//            .teamStock(activityTeamProductSkuAddModel.getTeamStock())
//            .teamPrice(activityTeamProductSkuAddModel.getTeamPrice())
//            .build();
//  }


}
